@@ -1,29 +1,24 @@
 import logging
 from contextlib import asynccontextmanager
-from datetime import datetime, UTC
+from datetime import UTC, datetime
+from enum import Enum
 from http import HTTPStatus
 from json import dumps
 from typing import AsyncGenerator, Literal, Mapping, Sequence
 from uuid import uuid4
 
-from aiohttp import ClientResponse, ClientSession, client_exceptions
-from pydantic import HttpUrl
+from aiohttp import ClientResponse, ClientSession, ClientTimeout, client_exceptions
 
 from python3_commons import audit
 from python3_commons.conf import s3_settings
 from python3_commons.helpers import request_to_curl
 from python3_commons.serializers.json import CustomJSONEncoder
 
-
 logger = logging.getLogger(__name__)
 
 
 async def _store_response_for_audit(
-        response: ClientResponse,
-        audit_name: str,
-        uri_path: str,
-        method: str,
-        request_id: str
+    response: ClientResponse, audit_name: str, uri_path: str, method: str, request_id: str
 ):
     response_text = await response.text()
 
@@ -35,21 +30,22 @@ async def _store_response_for_audit(
         await audit.write_audit_data(
             s3_settings,
             f'{date_path}/{audit_name}/{uri_path}/{method}_{timestamp}_{request_id}_response.txt',
-            response_text.encode('utf-8')
+            response_text.encode('utf-8'),
         )
 
 
 @asynccontextmanager
 async def request(
     client: ClientSession,
-    base_url: HttpUrl,
+    base_url: str,
     uri: str,
     query: Mapping | None = None,
     method: Literal['get', 'post', 'put', 'patch', 'options', 'head', 'delete'] = 'get',
     headers: Mapping | None = None,
     json: Mapping | Sequence | str | None = None,
     data: bytes | None = None,
-    audit_name: str | None = None
+    timeout: ClientTimeout | Enum | None = None,
+    audit_name: str | None = None,
 ) -> AsyncGenerator[ClientResponse]:
     now = datetime.now(tz=UTC)
     date_path = now.strftime('%Y/%m/%d')
@@ -57,7 +53,7 @@ async def request(
     request_id = str(uuid4())[-12:]
     uri_path = uri[:-1] if uri.endswith('/') else uri
     uri_path = uri_path[1:] if uri_path.startswith('/') else uri_path
-    url = f'{u[:-1] if (u := str(base_url)).endswith('/') else u}{uri}'
+    url = f'{u[:-1] if (u := str(base_url)).endswith("/") else u}{uri}'
 
     if audit_name:
         curl_request = None
@@ -72,7 +68,7 @@ async def request(
             await audit.write_audit_data(
                 s3_settings,
                 f'{date_path}/{audit_name}/{uri_path}/{method}_{timestamp}_{request_id}_request.txt',
-                curl_request.encode('utf-8')
+                curl_request.encode('utf-8'),
             )
     client_method = getattr(client, method)
 
@@ -80,7 +76,7 @@ async def request(
 
     try:
         if method == 'get':
-            async with client_method(url, params=query, headers=headers) as response:
+            async with client_method(url, params=query, headers=headers, timeout=timeout) as response:
                 if audit_name:
                     await _store_response_for_audit(response, audit_name, uri_path, method, request_id)
 
@@ -107,7 +103,7 @@ async def request(
                 else:
                     headers = {'Content-Type': 'application/json'}
 
-            async with client_method(url, params=query, data=data, headers=headers) as response:
+            async with client_method(url, params=query, data=data, headers=headers, timeout=timeout) as response:
                 if audit_name:
                     await _store_response_for_audit(response, audit_name, uri_path, method, request_id)
 
